validate

Function validate 

pub fn validate(
    predicates: &[Predicate],
    effect: &Effect,
    proves_double_submission: bool,
) -> Result<(SuotarEndpoint, Stage), FaultProblem>
Rejects a fault that could never fire, and the one combination that would fire and be wrong.