pub struct FaultSpec {
pub id: String,
pub when: WhenSpec,
pub then: Effect,
pub lifetime: Lifetime,
pub proves_double_submission: bool,
}Fields
id: Stringwhen: WhenSpecthen: Effectlifetime: Lifetimeproves_double_submission: boolRequired to arm the one combination that would otherwise pin a double submission into a green build.